function z=cgrid(xmin,xmax,nx,ymin,ymax,ny,ifpolar,x0,y0)
% z=cgrid(xmin,xmax,nx,ymin,ymax,ny,ifpolar,x0,y0)
% Return an nx by ny array of evenly spaced complex numbers.
%
%  xmin,xmax,nx       x-limits and number of x values
%  ymin,ymax,ny       y-limits and number of y values
%  ifpolar            If this parameter is present then a
%                     polar grid is generated with x <=> r
%                     and y <=> theta (degrees).
%  x0,y0              Center coordinates for a polar grid.
%                     Default is (0,0).

%           H.B.Wilson, Spring 1989
i=sqrt(-1);
if xmax==xmin, dx=xmin+eps; nx=1;
else, dx=(xmax-xmin)/(nx-1); end
if ymax==ymin, dy=ymin+eps; ny=1;
else, dy=(ymax-ymin)/(ny-1); end
if nargin==6
  z=(xmin:dx:xmax)'*ones(1,ny)+i*ones(nx,1)*(ymin:dy:ymax);
else
 z=(xmin:dx:xmax)'*exp((i*pi/180)*(ymin:dy:ymax));
 if nargin>7, z=z+(x0+i*y0); end
end
