function [zeta,z,theta,tau]=ellipse(aoverb,ntheta,ntrms)
%  [zeta,z,theta,tau]=ellipse(aoverb,ntheta,ntrms)
% Compute points to map the interior of an ellipse onto
% the interior of a circle. The correspondence is
%        ep=(a/b-1)/(a/b+1); i=sqrt(-1)
%     z=(1+ep)*cos(tau)+i*(1-ep)*sin(tau)
%       zeta=cos(theta)+i*sin(theta)
% See P. Henrici, Applied Complex Analysis, Vol 3, page 391

%     H.B.Wilson, Spring 1989
tau=(0:2*pi/ntheta:2*pi)'; ep=(aoverb-1)/(aoverb+1);
i=sqrt(-1); z=exp(i*tau); z=z+ep*conj(z);
j=1:ntrms;  ep=ep.^j; ep=ep./(j.*(1+ep.*ep));
theta=tau+2*( sin((2*tau+pi)*j)*ep'); zeta=exp(i*theta);
